#
# spec file for package password-store
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           password-store
Version:        1.7.3
Release:        bp153.1.14
Summary:        Utility to store, retrieve, generate and synchronize passwords
License:        GPL-2.0-or-later
Group:          Productivity/Other
URL:            https://zx2c4.com/projects/%{name}/
Source:         https://git.zx2c4.com/password-store/snapshot/%{name}-%{version}.tar.xz
BuildRequires:  bash-completion
BuildRequires:  git
BuildRequires:  gpg2
BuildRequires:  qrencode
BuildRequires:  tree
BuildRequires:  xz
BuildRequires:  zsh
Requires:       gpg2
Requires:       qrencode
Requires:       tree >= 1.7.0
Recommends:     pwgen
Requires:       xclip
Suggests:       git
BuildArch:      noarch
%if 0%{?suse_version} > 1320
BuildRequires:  fish
%endif

%description
With password-store, each password lives inside of a gpg encrypted file whose
filename is the title of the website or resource that requires the password.
These encrypted files may be organized into meaningful folder hierarchies,
copied from computer to computer, and, in general, manipulated using standard
command line file management utilities.

%package        dmenu
Summary:        A dmenu interface to the "pass" program
Group:          Productivity/Other
Requires:       dmenu
Recommends:     xdotool
BuildArch:      noarch

%description    dmenu
A dmenu interface to "pass", a password manager.

%prep
%autosetup
for shell_script in src/%{name}.sh contrib/dmenu/passmenu; do
    sed -i "s|#\!/usr/bin/env bash|#\!/bin/bash|" $shell_script
done

%build

%install
%make_install FISHCOMP_PATH=%{buildroot}%{_datadir}/fish/completions WITH_ALLCOMP="yes"
install -p -D -m 0755 contrib/dmenu/passmenu %{buildroot}%{_bindir}/passmenu

%check
%if 0%{?suse_version} >= 1320
make test %{?_smp_mflags}
%endif

%files
%license COPYING
%doc README
%{_mandir}/man1/pass.1%{?ext_man}
%{_bindir}/pass
%if 0%{?suse_version} <= 1320
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%endif
%{_datadir}/bash-completion/completions/pass
%{_datadir}/fish/vendor_completions.d/pass.fish
%{_datadir}/zsh/site-functions/_pass

%files dmenu
%doc contrib/dmenu/README.md
%{_bindir}/passmenu

%changelog
* Thu Apr 11 2019 Dan Čermák <dcermak@suse.com>
- small fixes to the pass spec file:
  * cleanup rpmlint warnings
  * require xclip instead of recommending it
  * preserve timestamps of fish completion files during installation
* Mon Aug  6 2018 kbabioch@suse.com
- Update to 1.7.3 (bugfix release)
  * Simplify filename matching in redact_pass.vim
  * Do not put passwords in herestrings
  * Do not set foreground color for generated password
  * Add custom bash completion for extensions
  * show: do not store binary data in bash vars
* Sun Jul 29 2018 jengelh@inai.de
- Use noun phrase in summary. Fix double meaning of "pass".
* Fri Jun 15 2018 kbabioch@suse.com
- Update to 1.7.2
  * Large number of bug fixes
  * Fixed the signature verification routine that parses the output of GnuPG.
    Previously, it was prone to spoofing of file signatures and allowed
    attackers to inject additional encryption keys (bsc#1097774
    CVE-2018-12356).
- Applied spec-cleaner
* Thu Nov  9 2017 aavindraa@gmail.com
- Version bump 1.7.1
  * Bug Fixes
  * Add compatibility with GnuPG 2.2.19
  * Uniformly use the $GPG variable
  * Do the correct thing with subkeys when reencrypting
  * Fix test suite on OS X
- Drop password-store-gpg-2.1.patch
  * merged in 6f867674272a03273212259b9039c9356a6ed90
- clean spec file with spec-cleaner
- use %%make_install macro
* Mon Mar 20 2017 werner@suse.de
- Update password-store-gpg-2.1.patch to upstream version done
  by Andreas Stieger
* Fri Mar 10 2017 werner@suse.de
- Version bump 1.7
  * Features
  * Extensions: pass can now load user-defined extensions from a system
    directory or a user directory. There's already a nice ecosystem of
    extensions being built, even at this early stage. See the pass man page for
    more information.
  * Signatures: there is now an option to enforce signatures of the .gpg-id file
    and extensions using an environment variable.
  * QRCodes: generate and show have now learned the --qrcode/-q switch. Note to
    package maintainers: this adds a dependency on the popular qrencode package.
  * Password generation: rather than use pwgen, we now use /dev/urandom more
    directly, which results in more assured password security, as well as
    customizable character sets, via an environment variable. See the pass man
    page for more information on this customization. Package maintainers: you
    may now drop the dependency on pwgen.
  * Importers: there now are several more importers. More and more folks are
    moving to pass!
  * Selectable clipping: you can now specify which line you wish to copy to the
    clipboard or display with a qrcode when using -c or -q.
  * Git discovery: The PASSWORD_STORE_GIT environment variable has been removed,
    and instead pass will automatically choose the git repository closest to the
    file being modified (but not out of the actual password store itself). This
    should help people who like to nest git repos for different organizations.
  * Bug fixes: too many to count.
- New dependency qrencode
- Make pwgen a recommended tool
- Add patch password-store-gpg-2.1.patch to be able to handle new gpg behaviour
  boo#1028867
* Thu Jan 29 2015 tampakrap@opensuse.org
- Add conditionals on dependencies that don't exist on older distros
- Disable tests in older distros where the dependencies don't satisfy them
* Wed Jan 28 2015 tampakrap@opensuse.org
- Version bump 1.6.5:
  * 1.6.4 Changelog:
  * Features:
  * "add" is an alias of "insert"
  * `pass edit` will no longer make a commit if the password does not change
  * Symbolic links are now followed
  * Remove gpg agent check, due to the auto-starting gpg-agent in GnuPG 2.1
  * Bug Fixes:
  * Avoid trailing slash in `pass grep`
  * Account for $CLIP_TIME in messages
  * revelation2pass, keepassx2pass, and other script improvements
  * Fix .gpg extension in tree listings, and preserve colors
  * Improved support for getopt on OSX
  * Updates for zsh and fish completion autoloading
  * Always preserve TTY for pinentry
  * Only use encryption subkeys
  * Better clip error messages
  * No longer use hidden recipients
  * 1.6.5 Changelog:
  * Features:
  * Support Gpg4win alongside Cygwin
  * Bug Fixes:
  * Work around unit tests bug with GnuPG 2.1.0 and 2.1.1
  * Manually migrate unit tests keys to GnuPG 2.1 series
  * Restore support for GnuPG 2.0 series
- Add a few builddeps so that we don't own the dirs of the completion files
* Tue Jul 22 2014 tampakrap@opensuse.org
- Version bump 1.6.3 (no upstream changelog)
- Upstream added tests, enable them in the package (added according Build deps)
- New subpackage password-store-dmenu, that adds passmenu binary
  It is a dmenu interface to pass
- Installation of completion files is fully and properly handled by the Makefile
- Depend on tree 1.7.0
* Tue Jul 22 2014 tampakrap@opensuse.org
- Version bump 1.5.0 (no upstream changelog)
- (not updating to 1.6.3 yet because it requires tree 1.7.0)
- fix installation of completion files (based on 1.6.3 Makefile)
- spec-cleaner
* Wed Jun  5 2013 tchatzimichos@suse.com
- Fix formatting
* Thu Mar 21 2013 tchatzimichos@suse.com
- Fix previous commit: Properly rename zsh completion file to _pass
* Thu Mar 21 2013 tchatzimichos@suse.com
- Rename zsh completion file to _zsh in order to make it detectable by zsh
* Wed Mar 20 2013 tchatzimichos@suse.com
- Add dependencies
* Mon Mar 18 2013 tchatzimichos@suse.com
- Initial commit of password-store package, version 1.4.2
